class InvalidInlineKeyboardButtonType(Exception):
    pass


class InvalidInlineKeyboardButtonPosition(Exception):
    pass


class InvalidChatAction(Exception):
    pass


class InvalidParseMode(Exception):
    pass


class InvalidUpdateType(Exception):
    pass


class InvalidMediaType(Exception):
    pass
